==> Paws-0.02.tar.gz: Paws-0.02/lib/Paws/ECS/DeleteCluster.pm <==

package Paws::ECS::DeleteCluster {
  use Moose;
  has cluster => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteCluster');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::ECS::DeleteClusterResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
}
1;

### main pod documentation begin ###

=head1 NAME

Paws::ECS::DeleteCluster - Arguments for method DeleteCluster on Paws::ECS

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteCluster on the 
Amazon EC2 Container Service service. Use the attributes of this class
as arguments to method DeleteCluster.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to DeleteCluster.

As an example:

  $service_obj->DeleteCluster(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 B<REQUIRED> cluster => Str

  

The short name or full Amazon Resource Name (ARN) of the cluster that
you want to delete.












=head1 SEE ALSO

This class forms part of L<Paws>, and documents parameters for DeleteCluster in Paws::ECS

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.15.tar.gz: Paws-0.15/lib/Paws/ECS/DeleteCluster.pm <==

package Paws::ECS::DeleteCluster;
  use Moose;
  has cluster => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteCluster');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::ECS::DeleteClusterResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::ECS::DeleteCluster - Arguments for method DeleteCluster on Paws::ECS

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteCluster on the 
Amazon EC2 Container Service service. Use the attributes of this class
as arguments to method DeleteCluster.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to DeleteCluster.

As an example:

  $service_obj->DeleteCluster(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 B<REQUIRED> cluster => Str

  

The short name or full Amazon Resource Name (ARN) of the cluster that
you want to delete.












=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteCluster in L<Paws::ECS>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
